@@ -29,7 +29,7 @@ test_that("daily works", {
 test_that("radiation works", {
     skip_if_offline()
     skip_on_cran()
-    skip("radiation data doesn't seem to be available.")
+    # skip("radiation data doesn't seem to be available.")
     dates <- seq.Date(lubridate::today() - 50, lubridate::today() - 45, by = "1 day")
     results <- GetSMNData(dates, type = "radiation")
 
